@@ -1,7 +1,7 @@
 package OpenGL::Sandbox;
-BEGIN { $OpenGL::Sandbox::VERSION = '0.01_1'; # TRIAL }
+BEGIN { $OpenGL::Sandbox::VERSION = '0.02_01'; } # TRIAL
 
-$OpenGL::Sandbox::VERSION = '0.011';use v5.14; # I can aim for older upon request.  Not expecting any requests though.
+$OpenGL::Sandbox::VERSION = '0.0201';use v5.14; # I can aim for older upon request.  Not expecting any requests though.
 use strict;
 use warnings;
 use Try::Tiny;
@@ -69,16 +69,15 @@ sub import {
 			splice(@_, $_, 1);
 		}
 		elsif ($arg =~ /^gl[a-zA-Z]/) {
-			push @gl_fn, $arg;
-			splice(@_, $_, 1);
+			# Let local methods in this package override external ones
+			unless ($class->can($arg)) {
+				push @gl_fn, $arg;
+				splice(@_, $_, 1);
+			}
 		}
 	}
-	if (@gl_const) {
-		$class->_import_gl_constants_into($caller, @gl_const);
-	}
-	if (@gl_fn) {
-		eval "package $caller; $OpenGLModule->import(\@gl_fn); 1" or die $@;
-	}
+	$class->_import_gl_constants_into($caller, @gl_const) if @gl_const;
+	$class->_import_gl_functions_into($caller, @gl_fn) if @gl_fn;
 	# Let the real Exporter module handle anything remaining in @_
 	goto \&Exporter::import;
 }
@@ -102,23 +101,54 @@ sub _import_gl_constants_into {
 	*{ $into . '::' . $_ }= $class->can($_) for @names;
 }
 
+sub _import_gl_functions_into {
+	my ($class, $into, @names)= @_;
+	eval "package $into; $OpenGLModule->import(\@names); 1" or die $@;
+}
+
 
 sub make_context {
 	my (%opts)= @_;
+	# Check for geometry specification on command line
+	my ($geom_spec, $w,$h,$l,$t);
+	for (0..$#ARGV) {
+		if ($ARGV[$_] =~ /^--?geometry(?:=(.*))?/) {
+			$geom_spec= $1 // $ARGV[$_+1];
+			last;
+		}
+	}
+	# Also check environment variable
+	$geom_spec //= $ENV{OPENGL_SANDBOX_GEOMETRY};
+	if (defined $geom_spec
+		&& (($w, $h, $l, $t)= ($geom_spec =~ /^(\d+)x(\d+)([-+]\d+)?([-+]\d+)?/))
+	) {
+		$opts{width} //= $w;
+		$opts{height} //= $h;
+		$opts{x} //= $l if defined $l;
+		$opts{y} //= $t if defined $t;
+	}
 	# Try X11 first, because lightest weight
 	my $provider= $ENV{OPENGL_SANDBOX_CONTEXT_PROVIDER};
 	$provider //=
-		eval 'require X11::GLX::DWIM; 1;' ? 'X11::GLX::DWIM'
-		: eval 'require SDLx::App; 1;' ? 'SDLx::App'
+		eval('require X11::GLX::DWIM; 1;') ? 'X11::GLX::DWIM'
+		: eval('require SDLx::App; 1;') ? 'SDLx::App'
 		: croak "make_context needs one of X11::GLX or SDL to be installed";
 	if ($provider eq 'X11::GLX' || $provider eq 'X11::GLX::DWIM') {
 		require X11::GLX::DWIM;
 		my $glx= X11::GLX::DWIM->new();
 		my $visible= $opts{visible} // 1;
 		if ($visible) {
-			$glx->target({ window => { width => $opts{width} // 400, height => $opts{height} // 400 }});
+			$glx->target({ window => {
+				x => $opts{x} // 0,
+				y => $opts{y} // 0,
+				width => $opts{width} // 400,
+				height => $opts{height} // 400
+			}});
 		} else {
-			$glx->target({ pixmap => { width => $opts{width} // 256, height => $opts{height} // 256 }});
+			$glx->target({ pixmap => {
+				width => $opts{width} // 256,
+				height => $opts{height} // 256
+			}});
 		}
 		$log->infof("Loaded X11::GLX::DWIM %s, target '%s', GLX Version %s, OpenGL version %s\n",
 			$glx->VERSION, $visible? 'window':'pixmap', $glx->glx_version, glGetString(GL_VERSION));
@@ -128,15 +158,29 @@ sub make_context {
 	# Else try SDL
 	elsif ($provider eq 'SDL' || $provider eq 'SDLx::App') {
 		my $sdl_subclass= _init_sdl_wrapper();
+		# TODO: Figure out best way to create invisible SDL window
+		if (defined $opts{visible} && !$opts{visible}) {
+			$opts{x}= -100;
+			$opts{width}= $opts{height}= 1;
+		}
+		# This is the only option I know of for SDL to set initial window placement
+		local $ENV{SDL_VIDEO_WINDOW_POS}= ($opts{x}//0).','.($opts{y}//0)
+			if defined $opts{x} || defined $opts{y};
+		my $flags= 0;
+		$flags |= SDL::SDL_NOFRAME() if $opts{noframe};
+		$flags |= SDL::SDL_FULLSCREEN() if $opts{fullscreen};
 		my $sdl= $sdl_subclass->new(
 			title  => $opts{title} // 'OpenGL',
-			width  => $opts{width} // 400,
-			height => $opts{height} // 400,
+			(defined $opts{width}?  ( width  => $opts{width} ) : ()),
+			(defined $opts{height}? ( height => $opts{height} ) : ()),
+			($flags?                ( flags => (SDL::SDL_ANYFORMAT() | $flags) ) : ()),
 			opengl => 1,
+			exit_on_quit => 1,
 		);
 		$log->infof("Loaded SDLx::App %s, OpenGL version %s\n", $sdl->VERSION, glGetString(GL_VERSION));
 		return $sdl;
 	}
+	# TODO: else try Prima
 	else {
 		die "Unhandled context provider $provider";
 	}
@@ -194,7 +238,7 @@ OpenGL::Sandbox - Rapid-prototyping utilities for OpenGL
 
 =head1 VERSION
 
-version 0.01_1
+version 0.02_01
 
 =head1 EXPORTS
 
@@ -232,14 +276,52 @@ in the future.
 
 =head2 make_context
 
+  my $context= make_context( %opts );
+
 Pick the lightest smallest module that can get a window set up for rendering.
-This tries: L<X11::GLX>, and L<SDLx::App> in that order.
+This tries: L<X11::GLX>, and L<SDLx::App> in that order.  You can override the detection
+with environment variable C<OPENGL_SANDBOX_CONTEXT_PROVIDER>.
 It assumes you don't have any desire to receive user input and just want to render some stuff.
 If you do actually have a preference, you should just invoke that package yourself.
 
 Always returns an object whose scope controls the lifecycle of the window, and that object
 always has a C<swap_buffers> method.
 
+This attempts to automatically pick up the window geometry, either from a "--geometry=" option
+or from the environment variable C<OPENGL_SANDBOX_GEOMETRY>.  The Geometry value is in X11
+notation of C<"${WIDTH}x${HEIGHT}+$X+$Y"> except that negative C<X>,C<Y> (from right edge) are
+not supported.
+
+Not all options have been implemented for each source, but the list of possibilities is:
+
+=over
+
+=item x, y, width, height
+
+Set the placement and dimensions of the created window.
+
+=item visible
+
+Defaults to true, but if false, attempts to create an off-screen GL context.
+
+=item fullscreen
+
+Attempts to create a full-screen context.
+
+=item noframe
+
+Attempts to create a window without window border decorations.
+
+=item title
+
+Window title
+
+=back
+
+Note that if you're using Classic OpenGL (V1) you also need to set up the projection matrix
+to something more useful than the defaults before rendering anything.
+See L<OpenGL::Sandbox::V1/setup_projection>.
+
 =head2 get_gl_errors
 
 Returns the symbolic names of any pending OpenGL errors, as a list.
