@@ -1,7 +1,7 @@
 package OpenGL::Sandbox::Texture;
-BEGIN { $OpenGL::Sandbox::Texture::VERSION = '0.01_1'; # TRIAL }
+BEGIN { $OpenGL::Sandbox::Texture::VERSION = '0.02_01'; } # TRIAL
 
-$OpenGL::Sandbox::Texture::VERSION = '0.011';use Moo;
+$OpenGL::Sandbox::Texture::VERSION = '0.0201';use Moo;
 use Carp;
 use Try::Tiny;
 use OpenGL::Sandbox qw(
@@ -151,12 +151,8 @@ sub convert_png {
 }
 
 # Pull in the C file and make sure it has all the C libs available
-use Inline
+use OpenGL::Sandbox::Texture::Inline
 	C => do { my $x= __FILE__; $x =~ s|\.pm|\.c|; Cwd::abs_path($x) },
-	(defined $OpenGL::Sandbox::Texture::VERSION? (
-		NAME => __PACKAGE__,
-		VERSION => __PACKAGE__->VERSION
-	) : () ),
 	INC => '-I'.do{ my $x= __FILE__; $x =~ s|/[^/]+$|/|; Cwd::abs_path($x) }.' -I/usr/include/ffmpeg',
 	LIBS => '-lGL -lswscale',
 	CCFLAGSEX => '-Wall -g3 -Os';
@@ -175,7 +171,7 @@ OpenGL::Sandbox::Texture - Wrapper object for OpenGL texture
 
 =head1 VERSION
 
-version 0.01_1
+version 0.02_01
 
 =head1 ATTRIBUTES
 
